@@ -152,8 +152,10 @@ cat(format(a)) # basic tests of format.earth
 cat(format(a, digits=4))
 # cat(format(a, use.names=FALSE))
 cat(format(a, style="pmax"))
+cat(format(a, style="max"))
 cat(format(a, style="bf"))
 cat(format(a, use.names=FALSE, style="p"))
+cat(format(a, use.names=FALSE, style="m"))
 a <- earth(Volume ~ Girth*Height, data = trees, pmethod="none")
 cat(format(a))
 cat(format(a, colon.char="*"))
